==> aws-cdk-lib-2.20.0-sources.jar: software/amazon/awscdk/services/opensearchservice/EngineVersion.java <==
package software.amazon.awscdk.services.opensearchservice;

/**
 * OpenSearch version.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Domain domain = Domain.Builder.create(this, "Domain")
 *         .version(EngineVersion.OPENSEARCH_1_0)
 *         .ebs(EbsOptions.builder()
 *                 .volumeSize(100)
 *                 .volumeType(EbsDeviceVolumeType.GENERAL_PURPOSE_SSD)
 *                 .build())
 *         .nodeToNodeEncryption(true)
 *         .encryptionAtRest(EncryptionAtRestOptions.builder()
 *                 .enabled(true)
 *                 .build())
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.55.1 (build 07d2d90)", date = "2022-04-07T11:16:45.041Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_opensearchservice.EngineVersion")
public class EngineVersion extends software.amazon.jsii.JsiiObject {

    protected EngineVersion(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected EngineVersion(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        ELASTICSEARCH_1_5 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_1_5", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_2_3 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_2_3", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_5_1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_5_1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_5_3 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_5_3", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_5_5 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_5_5", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_5_6 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_5_6", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_6_0 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_6_0", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_6_2 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_6_2", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_6_3 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_6_3", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_6_4 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_6_4", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_6_5 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_6_5", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_6_7 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_6_7", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_6_8 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_6_8", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_7_1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_7_1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_7_10 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_7_10", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_7_4 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_7_4", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_7_7 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_7_7", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_7_8 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_7_8", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_7_9 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_7_9", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        OPENSEARCH_1_0 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "OPENSEARCH_1_0", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        OPENSEARCH_1_1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "OPENSEARCH_1_1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        OPENSEARCH_1_2 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "OPENSEARCH_1_2", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
    }

    /**
     * Custom ElasticSearch version.
     * <p>
     * @param version custom version number. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.opensearchservice.EngineVersion elasticsearch(final @org.jetbrains.annotations.NotNull java.lang.String version) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "elasticsearch", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class), new Object[] { java.util.Objects.requireNonNull(version, "version is required") });
    }

    /**
     * Custom OpenSearch version.
     * <p>
     * @param version custom version number. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.opensearchservice.EngineVersion openSearch(final @org.jetbrains.annotations.NotNull java.lang.String version) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "openSearch", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class), new Object[] { java.util.Objects.requireNonNull(version, "version is required") });
    }

    /**
     * AWS Elasticsearch 1.5.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_1_5;

    /**
     * AWS Elasticsearch 2.3.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_2_3;

    /**
     * AWS Elasticsearch 5.1.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_5_1;

    /**
     * AWS Elasticsearch 5.3.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_5_3;

    /**
     * AWS Elasticsearch 5.5.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_5_5;

    /**
     * AWS Elasticsearch 5.6.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_5_6;

    /**
     * AWS Elasticsearch 6.0.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_6_0;

    /**
     * AWS Elasticsearch 6.2.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_6_2;

    /**
     * AWS Elasticsearch 6.3.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_6_3;

    /**
     * AWS Elasticsearch 6.4.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_6_4;

    /**
     * AWS Elasticsearch 6.5.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_6_5;

    /**
     * AWS Elasticsearch 6.7.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_6_7;

    /**
     * AWS Elasticsearch 6.8.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_6_8;

    /**
     * AWS Elasticsearch 7.1.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_7_1;

    /**
     * AWS Elasticsearch 7.10.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_7_10;

    /**
     * AWS Elasticsearch 7.4.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_7_4;

    /**
     * AWS Elasticsearch 7.7.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_7_7;

    /**
     * AWS Elasticsearch 7.8.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_7_8;

    /**
     * AWS Elasticsearch 7.9.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_7_9;

    /**
     * AWS OpenSearch 1.0.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion OPENSEARCH_1_0;

    /**
     * AWS OpenSearch 1.1.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion OPENSEARCH_1_1;

    /**
     * AWS OpenSearch 1.2.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion OPENSEARCH_1_2;

    /**
     * engine version identifier.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getVersion() {
        return software.amazon.jsii.Kernel.get(this, "version", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}

==> aws-cdk-lib-2.35.0-sources.jar: software/amazon/awscdk/services/opensearchservice/EngineVersion.java <==
package software.amazon.awscdk.services.opensearchservice;

/**
 * OpenSearch version.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Domain domain = Domain.Builder.create(this, "Domain")
 *         .version(EngineVersion.OPENSEARCH_1_0)
 *         .ebs(EbsOptions.builder()
 *                 .volumeSize(100)
 *                 .volumeType(EbsDeviceVolumeType.GENERAL_PURPOSE_SSD)
 *                 .build())
 *         .nodeToNodeEncryption(true)
 *         .encryptionAtRest(EncryptionAtRestOptions.builder()
 *                 .enabled(true)
 *                 .build())
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.63.2 (build a8a8833)", date = "2022-08-02T19:52:00.816Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_opensearchservice.EngineVersion")
public class EngineVersion extends software.amazon.jsii.JsiiObject {

    protected EngineVersion(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected EngineVersion(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        ELASTICSEARCH_1_5 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_1_5", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_2_3 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_2_3", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_5_1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_5_1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_5_3 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_5_3", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_5_5 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_5_5", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_5_6 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_5_6", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_6_0 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_6_0", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_6_2 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_6_2", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_6_3 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_6_3", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_6_4 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_6_4", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_6_5 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_6_5", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_6_7 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_6_7", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_6_8 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_6_8", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_7_1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_7_1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_7_10 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_7_10", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_7_4 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_7_4", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_7_7 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_7_7", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_7_8 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_7_8", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        ELASTICSEARCH_7_9 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "ELASTICSEARCH_7_9", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        OPENSEARCH_1_0 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "OPENSEARCH_1_0", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        OPENSEARCH_1_1 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "OPENSEARCH_1_1", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        OPENSEARCH_1_2 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "OPENSEARCH_1_2", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
        OPENSEARCH_1_3 = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "OPENSEARCH_1_3", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class));
    }

    /**
     * Custom ElasticSearch version.
     * <p>
     * @param version custom version number. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.opensearchservice.EngineVersion elasticsearch(final @org.jetbrains.annotations.NotNull java.lang.String version) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "elasticsearch", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class), new Object[] { java.util.Objects.requireNonNull(version, "version is required") });
    }

    /**
     * Custom OpenSearch version.
     * <p>
     * @param version custom version number. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.opensearchservice.EngineVersion openSearch(final @org.jetbrains.annotations.NotNull java.lang.String version) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.opensearchservice.EngineVersion.class, "openSearch", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.opensearchservice.EngineVersion.class), new Object[] { java.util.Objects.requireNonNull(version, "version is required") });
    }

    /**
     * AWS Elasticsearch 1.5.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_1_5;

    /**
     * AWS Elasticsearch 2.3.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_2_3;

    /**
     * AWS Elasticsearch 5.1.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_5_1;

    /**
     * AWS Elasticsearch 5.3.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_5_3;

    /**
     * AWS Elasticsearch 5.5.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_5_5;

    /**
     * AWS Elasticsearch 5.6.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_5_6;

    /**
     * AWS Elasticsearch 6.0.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_6_0;

    /**
     * AWS Elasticsearch 6.2.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_6_2;

    /**
     * AWS Elasticsearch 6.3.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_6_3;

    /**
     * AWS Elasticsearch 6.4.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_6_4;

    /**
     * AWS Elasticsearch 6.5.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_6_5;

    /**
     * AWS Elasticsearch 6.7.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_6_7;

    /**
     * AWS Elasticsearch 6.8.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_6_8;

    /**
     * AWS Elasticsearch 7.1.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_7_1;

    /**
     * AWS Elasticsearch 7.10.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_7_10;

    /**
     * AWS Elasticsearch 7.4.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_7_4;

    /**
     * AWS Elasticsearch 7.7.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_7_7;

    /**
     * AWS Elasticsearch 7.8.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_7_8;

    /**
     * AWS Elasticsearch 7.9.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion ELASTICSEARCH_7_9;

    /**
     * AWS OpenSearch 1.0.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion OPENSEARCH_1_0;

    /**
     * AWS OpenSearch 1.1.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion OPENSEARCH_1_1;

    /**
     * AWS OpenSearch 1.2.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion OPENSEARCH_1_2;

    /**
     * AWS OpenSearch 1.3.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.opensearchservice.EngineVersion OPENSEARCH_1_3;

    /**
     * engine version identifier.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getVersion() {
        return software.amazon.jsii.Kernel.get(this, "version", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}
